/*     */ package org.apache.batik.svggen;
/*     */ 
/*     */ import java.util.HashMap;
/*     */ import java.util.Iterator;
/*     */ import java.util.Map;
/*     */ import org.apache.batik.ext.awt.g2d.GraphicContext;
/*     */ import org.apache.batik.ext.awt.g2d.TransformStackElement;
/*     */ import org.w3c.dom.Element;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class DOMGroupManager
/*     */   implements SVGSyntax, ErrorConstants
/*     */ {
/*     */   public static final short DRAW = 1;
/*     */   public static final short FILL = 16;
/*     */   protected GraphicContext gc;
/*     */   protected DOMTreeManager domTreeManager;
/*     */   protected SVGGraphicContext groupGC;
/*     */   protected Element currentGroup;
/*     */   
/*     */   public DOMGroupManager(GraphicContext gc, DOMTreeManager domTreeManager) {
/*  94 */     if (gc == null) {
/*  95 */       throw new SVGGraphics2DRuntimeException("gc should not be null");
/*     */     }
/*  97 */     if (domTreeManager == null) {
/*  98 */       throw new SVGGraphics2DRuntimeException("domTreeManager should not be null");
/*     */     }
/* 100 */     this.gc = gc;
/* 101 */     this.domTreeManager = domTreeManager;
/*     */ 
/*     */     
/* 104 */     recycleCurrentGroup();
/*     */ 
/*     */     
/* 107 */     this.groupGC = domTreeManager.gcConverter.toSVG(gc);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 115 */   void recycleCurrentGroup() { this.currentGroup = this.domTreeManager.getDOMFactory().createElementNS("http://www.w3.org/2000/svg", "g"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 124 */   public void addElement(Element element) { addElement(element, (short)17); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addElement(Element element, short method) {
/* 136 */     if (!this.currentGroup.hasChildNodes()) {
/* 137 */       this.currentGroup.appendChild(element);
/*     */       
/* 139 */       this.groupGC = this.domTreeManager.gcConverter.toSVG(this.gc);
/*     */       
/* 141 */       SVGGraphicContext deltaGC = processDeltaGC(this.groupGC, this.domTreeManager.defaultGC);
/*     */       
/* 143 */       this.domTreeManager.getStyleHandler().setStyle(this.currentGroup, deltaGC.getGroupContext(), this.domTreeManager.getGeneratorContext());
/*     */ 
/*     */       
/* 146 */       if ((method & true) == 0)
/*     */       {
/* 148 */         deltaGC.getGraphicElementContext().put("stroke", "none");
/*     */       }
/*     */       
/* 151 */       if ((method & 0x10) == 0)
/*     */       {
/* 153 */         deltaGC.getGraphicElementContext().put("fill", "none");
/*     */       }
/*     */       
/* 156 */       this.domTreeManager.getStyleHandler().setStyle(element, deltaGC.getGraphicElementContext(), this.domTreeManager.getGeneratorContext());
/*     */ 
/*     */       
/* 159 */       setTransform(this.currentGroup, deltaGC.getTransformStack());
/* 160 */       this.domTreeManager.appendGroup(this.currentGroup, this);
/*     */     }
/* 162 */     else if (this.gc.isTransformStackValid()) {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 168 */       SVGGraphicContext elementGC = this.domTreeManager.gcConverter.toSVG(this.gc);
/*     */       
/* 170 */       SVGGraphicContext deltaGC = processDeltaGC(elementGC, this.groupGC);
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 175 */       trimContextForElement(deltaGC, element);
/* 176 */       if (countOverrides(deltaGC) <= this.domTreeManager.maxGCOverrides) {
/* 177 */         this.currentGroup.appendChild(element);
/*     */ 
/*     */         
/* 180 */         if ((method & true) == 0)
/*     */         {
/* 182 */           deltaGC.getContext().put("stroke", "none");
/*     */         }
/*     */         
/* 185 */         if ((method & 0x10) == 0)
/*     */         {
/* 187 */           deltaGC.getContext().put("fill", "none");
/*     */         }
/*     */         
/* 190 */         this.domTreeManager.getStyleHandler().setStyle(element, deltaGC.getContext(), this.domTreeManager.getGeneratorContext());
/*     */ 
/*     */         
/* 193 */         setTransform(element, deltaGC.getTransformStack());
/*     */       
/*     */       }
/*     */       else {
/*     */         
/* 198 */         this.currentGroup = this.domTreeManager.getDOMFactory().createElementNS("http://www.w3.org/2000/svg", "g");
/*     */ 
/*     */         
/* 201 */         addElement(element, method);
/*     */       
/*     */       }
/*     */     
/*     */     }
/*     */     else {
/*     */       
/* 208 */       this.currentGroup = this.domTreeManager.getDOMFactory().createElementNS("http://www.w3.org/2000/svg", "g");
/*     */ 
/*     */       
/* 211 */       this.gc.validateTransformStack();
/* 212 */       addElement(element, method);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 223 */   protected int countOverrides(SVGGraphicContext deltaGC) { return deltaGC.getGroupContext().size(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void trimContextForElement(SVGGraphicContext svgGC, Element element) {
/* 230 */     String tag = element.getTagName();
/* 231 */     Map groupAttrMap = svgGC.getGroupContext();
/* 232 */     if (tag != null) {
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 237 */       Iterator iter = groupAttrMap.keySet().iterator();
/* 238 */       while (iter.hasNext()) {
/* 239 */         String attrName = (String)iter.next();
/* 240 */         SVGAttribute attr = SVGAttributeMap.get(attrName);
/* 241 */         if (attr != null && !attr.appliesTo(tag)) {
/* 242 */           groupAttrMap.remove(attrName);
/*     */         }
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void setTransform(Element element, TransformStackElement[] transformStack) {
/* 253 */     String transform = this.domTreeManager.gcConverter.toSVG(transformStack).trim();
/*     */     
/* 255 */     if (transform.length() > 0) {
/* 256 */       element.setAttributeNS(null, "transform", transform);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static SVGGraphicContext processDeltaGC(SVGGraphicContext gc, SVGGraphicContext referenceGc) {
/* 266 */     Map groupDelta = processDeltaMap(gc.getGroupContext(), referenceGc.getGroupContext());
/*     */     
/* 268 */     Map graphicElementDelta = gc.getGraphicElementContext();
/*     */     
/* 270 */     TransformStackElement[] gcTransformStack = gc.getTransformStack();
/* 271 */     TransformStackElement[] referenceStack = referenceGc.getTransformStack();
/* 272 */     int deltaStackLength = gcTransformStack.length - referenceStack.length;
/* 273 */     TransformStackElement[] deltaTransformStack = new TransformStackElement[deltaStackLength];
/*     */ 
/*     */     
/* 276 */     System.arraycopy(gcTransformStack, referenceStack.length, deltaTransformStack, 0, deltaStackLength);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 302 */     return new SVGGraphicContext(groupDelta, graphicElementDelta, deltaTransformStack);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   static Map processDeltaMap(Map map, Map referenceMap) {
/* 317 */     Map mapDelta = new HashMap();
/* 318 */     Iterator iter = map.keySet().iterator();
/* 319 */     while (iter.hasNext()) {
/* 320 */       String key = (String)iter.next();
/* 321 */       String value = (String)map.get(key);
/* 322 */       String refValue = (String)referenceMap.get(key);
/* 323 */       if (!value.equals(refValue))
/*     */       {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 331 */         mapDelta.put(key, value);
/*     */       }
/*     */     } 
/* 334 */     return mapDelta;
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svggen.jar!\org\apache\batik\svggen\DOMGroupManager.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */