/*     */ package org.apache.batik.svggen;
/*     */ 
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collections;
/*     */ import java.util.Iterator;
/*     */ import java.util.LinkedList;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import org.apache.batik.ext.awt.g2d.GraphicContext;
/*     */ import org.w3c.dom.Comment;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.NodeList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class DOMTreeManager
/*     */   implements SVGSyntax, ErrorConstants
/*     */ {
/*     */   int maxGCOverrides;
/*  77 */   protected final List groupManagers = Collections.synchronizedList(new ArrayList());
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  83 */   protected List genericDefSet = new LinkedList();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   SVGGraphicContext defaultGC;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Element topLevelGroup;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   SVGGraphicContextConverter gcConverter;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGGeneratorContext generatorContext;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGBufferedImageOp filterConverter;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected List otherDefs;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public DOMTreeManager(GraphicContext gc, SVGGeneratorContext generatorContext, int maxGCOverrides) {
/* 129 */     if (gc == null) {
/* 130 */       throw new SVGGraphics2DRuntimeException("gc should not be null");
/*     */     }
/* 132 */     if (maxGCOverrides <= 0) {
/* 133 */       throw new SVGGraphics2DRuntimeException("maxGcOverrides should be greater than zero");
/*     */     }
/* 135 */     if (generatorContext == null) {
/* 136 */       throw new SVGGraphics2DRuntimeException("generatorContext should not be null");
/*     */     }
/* 138 */     this.generatorContext = generatorContext;
/* 139 */     this.maxGCOverrides = maxGCOverrides;
/*     */ 
/*     */     
/* 142 */     recycleTopLevelGroup();
/*     */ 
/*     */     
/* 145 */     this.defaultGC = this.gcConverter.toSVG(gc);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addGroupManager(DOMGroupManager groupManager) {
/* 153 */     if (groupManager != null) {
/* 154 */       this.groupManagers.add(groupManager);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void removeGroupManager(DOMGroupManager groupManager) {
/* 162 */     if (groupManager != null) {
/* 163 */       this.groupManagers.remove(groupManager);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void appendGroup(Element group, DOMGroupManager groupManager) {
/* 175 */     this.topLevelGroup.appendChild(group);
/* 176 */     synchronized (this.groupManagers) {
/*     */ 
/*     */ 
/*     */       
/* 180 */       int nManagers = this.groupManagers.size();
/* 181 */       for (int i = 0; i < nManagers; i++) {
/* 182 */         DOMGroupManager gm = (DOMGroupManager)this.groupManagers.get(i);
/* 183 */         if (gm != groupManager) {
/* 184 */           gm.recycleCurrentGroup();
/*     */         }
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 193 */   protected void recycleTopLevelGroup() { recycleTopLevelGroup(true); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void recycleTopLevelGroup(boolean recycleConverters) {
/* 202 */     synchronized (this.groupManagers) {
/*     */ 
/*     */ 
/*     */       
/* 206 */       int nManagers = this.groupManagers.size();
/* 207 */       for (int i = 0; i < nManagers; i++) {
/* 208 */         DOMGroupManager gm = (DOMGroupManager)this.groupManagers.get(i);
/* 209 */         gm.recycleCurrentGroup();
/*     */       } 
/*     */     } 
/*     */ 
/*     */     
/* 214 */     this.topLevelGroup = this.generatorContext.domFactory.createElementNS("http://www.w3.org/2000/svg", "g");
/*     */ 
/*     */ 
/*     */     
/* 218 */     if (recycleConverters) {
/* 219 */       this.filterConverter = new SVGBufferedImageOp(this.generatorContext);
/*     */       
/* 221 */       this.gcConverter = new SVGGraphicContextConverter(this.generatorContext);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setTopLevelGroup(Element topLevelGroup) {
/* 232 */     if (topLevelGroup == null) {
/* 233 */       throw new SVGGraphics2DRuntimeException("topLevelGroup should not be null");
/*     */     }
/* 235 */     if (!"g".equalsIgnoreCase(topLevelGroup.getTagName())) {
/* 236 */       throw new SVGGraphics2DRuntimeException("topLevelGroup should be a group <g>");
/*     */     }
/* 238 */     recycleTopLevelGroup(false);
/* 239 */     this.topLevelGroup = topLevelGroup;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 247 */   public Element getRoot() { return getRoot(null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Element getRoot(Element svgElement) {
/* 255 */     Element svg = svgElement;
/*     */     
/* 257 */     if (svg == null) {
/* 258 */       svg = this.generatorContext.domFactory.createElementNS("http://www.w3.org/2000/svg", "svg");
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 263 */     if (this.gcConverter.getCompositeConverter().getAlphaCompositeConverter().requiresBackgroundAccess())
/*     */     {
/* 265 */       svg.setAttributeNS(null, "enable-background", "new");
/*     */     }
/*     */     
/* 268 */     if (this.generatorContext.generatorComment != null) {
/* 269 */       Comment generatorComment = this.generatorContext.domFactory.createComment(this.generatorContext.generatorComment);
/*     */       
/* 271 */       svg.appendChild(generatorComment);
/*     */     } 
/*     */ 
/*     */     
/* 275 */     applyDefaultRenderingStyle(svg);
/*     */     
/* 277 */     svg.appendChild(getGenericDefinitions());
/* 278 */     svg.appendChild(getTopLevelGroup());
/*     */     
/* 280 */     return svg;
/*     */   }
/*     */   
/*     */   public void applyDefaultRenderingStyle(Element element) {
/* 284 */     Map groupDefaults = this.defaultGC.getGroupContext();
/* 285 */     this.generatorContext.styleHandler.setStyle(element, groupDefaults, this.generatorContext);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Element getGenericDefinitions() {
/* 295 */     Element genericDefs = this.generatorContext.domFactory.createElementNS("http://www.w3.org/2000/svg", "defs");
/*     */ 
/*     */     
/* 298 */     Iterator iter = this.genericDefSet.iterator();
/* 299 */     while (iter.hasNext()) {
/* 300 */       genericDefs.appendChild((Element)iter.next());
/*     */     }
/*     */     
/* 303 */     genericDefs.setAttributeNS(null, "id", "genericDefs");
/* 304 */     return genericDefs;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 311 */   public ExtensionHandler getExtensionHandler() { return this.generatorContext.getExtensionHandler(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 320 */   void setExtensionHandler(ExtensionHandler extensionHandler) { this.generatorContext.setExtensionHandler(extensionHandler); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public List getDefinitionSet() {
/* 333 */     List defSet = this.gcConverter.getDefinitionSet();
/* 334 */     defSet.removeAll(this.genericDefSet);
/* 335 */     defSet.addAll(this.filterConverter.getDefinitionSet());
/* 336 */     if (this.otherDefs != null) {
/* 337 */       defSet.addAll(this.otherDefs);
/* 338 */       this.otherDefs = null;
/*     */     } 
/*     */ 
/*     */     
/* 342 */     this.filterConverter = new SVGBufferedImageOp(this.generatorContext);
/* 343 */     this.gcConverter = new SVGGraphicContextConverter(this.generatorContext);
/*     */     
/* 345 */     return defSet;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addOtherDef(Element definition) {
/* 353 */     if (this.otherDefs == null) {
/* 354 */       this.otherDefs = new LinkedList();
/*     */     }
/*     */     
/* 357 */     this.otherDefs.add(definition);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Element getTopLevelGroup() {
/* 368 */     boolean includeDefinitionSet = true;
/* 369 */     return getTopLevelGroup(includeDefinitionSet);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Element getTopLevelGroup(boolean includeDefinitionSet) {
/* 383 */     Element topLevelGroup = this.topLevelGroup;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 388 */     if (includeDefinitionSet) {
/* 389 */       List defSet = getDefinitionSet();
/* 390 */       if (defSet.size() > 0) {
/* 391 */         Element defElement = null;
/*     */         
/* 393 */         NodeList defsElements = topLevelGroup.getElementsByTagName("defs");
/*     */         
/* 395 */         if (defsElements.getLength() > 0) {
/* 396 */           defElement = (Element)defsElements.item(0);
/*     */         }
/* 398 */         if (defElement == null) {
/* 399 */           defElement = this.generatorContext.domFactory.createElementNS("http://www.w3.org/2000/svg", "defs");
/*     */ 
/*     */ 
/*     */           
/* 403 */           defElement.setAttributeNS(null, "id", this.generatorContext.idGenerator.generateID("defs"));
/*     */ 
/*     */ 
/*     */           
/* 407 */           topLevelGroup.insertBefore(defElement, topLevelGroup.getFirstChild());
/*     */         } 
/*     */ 
/*     */         
/* 411 */         Iterator iter = defSet.iterator();
/* 412 */         while (iter.hasNext()) {
/* 413 */           defElement.appendChild((Element)iter.next());
/*     */         }
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 420 */     recycleTopLevelGroup(false);
/*     */     
/* 422 */     return topLevelGroup;
/*     */   }
/*     */ 
/*     */   
/* 426 */   public SVGBufferedImageOp getFilterConverter() { return this.filterConverter; }
/*     */ 
/*     */ 
/*     */   
/* 430 */   public SVGGraphicContextConverter getGraphicContextConverter() { return this.gcConverter; }
/*     */ 
/*     */ 
/*     */   
/* 434 */   SVGGeneratorContext getGeneratorContext() { return this.generatorContext; }
/*     */ 
/*     */ 
/*     */   
/* 438 */   Document getDOMFactory() { return this.generatorContext.domFactory; }
/*     */ 
/*     */ 
/*     */   
/* 442 */   StyleHandler getStyleHandler() { return this.generatorContext.styleHandler; }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svggen.jar!\org\apache\batik\svggen\DOMTreeManager.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */