/*     */ package org.apache.batik.svggen;
/*     */ 
/*     */ import java.awt.Color;
/*     */ import java.awt.Composite;
/*     */ import java.awt.Font;
/*     */ import java.awt.Paint;
/*     */ import java.awt.RenderingHints;
/*     */ import java.awt.Shape;
/*     */ import java.awt.Stroke;
/*     */ import java.text.DecimalFormat;
/*     */ import java.text.DecimalFormatSymbols;
/*     */ import java.util.Locale;
/*     */ import org.w3c.dom.Document;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGGeneratorContext
/*     */   implements ErrorConstants
/*     */ {
/*     */   Document domFactory;
/*     */   ImageHandler imageHandler;
/*     */   GenericImageHandler genericImageHandler;
/*     */   ExtensionHandler extensionHandler;
/*     */   SVGIDGenerator idGenerator;
/*     */   StyleHandler styleHandler;
/*     */   String generatorComment;
/*     */   ErrorHandler errorHandler;
/*     */   boolean svgFont;
/*     */   GraphicContextDefaults gcDefaults;
/*     */   int precision;
/*     */   protected DecimalFormat decimalFormat;
/*     */   
/*     */   public static class GraphicContextDefaults
/*     */   {
/*     */     protected Paint paint;
/*     */     protected Stroke stroke;
/*     */     protected Composite composite;
/*     */     protected Shape clip;
/*     */     protected RenderingHints hints;
/*     */     protected Font font;
/*     */     protected Color background;
/*     */     
/* 137 */     public void setStroke(Stroke stroke) { this.stroke = stroke; }
/*     */ 
/*     */ 
/*     */     
/* 141 */     public Stroke getStroke() { return this.stroke; }
/*     */ 
/*     */ 
/*     */     
/* 145 */     public void setComposite(Composite composite) { this.composite = composite; }
/*     */ 
/*     */ 
/*     */     
/* 149 */     public Composite getComposite() { return this.composite; }
/*     */ 
/*     */ 
/*     */     
/* 153 */     public void setClip(Shape clip) { this.clip = clip; }
/*     */ 
/*     */ 
/*     */     
/* 157 */     public Shape getClip() { return this.clip; }
/*     */ 
/*     */ 
/*     */     
/* 161 */     public void setRenderingHints(RenderingHints hints) { this.hints = hints; }
/*     */ 
/*     */ 
/*     */     
/* 165 */     public RenderingHints getRenderingHints() { return this.hints; }
/*     */ 
/*     */ 
/*     */     
/* 169 */     public void setFont(Font font) { this.font = font; }
/*     */ 
/*     */ 
/*     */     
/* 173 */     public Font getFont() { return this.font; }
/*     */ 
/*     */ 
/*     */     
/* 177 */     public void setBackground(Color background) { this.background = background; }
/*     */ 
/*     */ 
/*     */     
/* 181 */     public Color getBackground() { return this.background; }
/*     */ 
/*     */ 
/*     */     
/* 185 */     public void setPaint(Paint paint) { this.paint = paint; }
/*     */ 
/*     */ 
/*     */     
/* 189 */     public Paint getPaint() { return this.paint; }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected SVGGeneratorContext(Document domFactory) {
/*     */     this.svgFont = false;
/*     */     this.precision = 4;
/*     */     this.decimalFormat = decimalFormats[this.precision];
/* 205 */     setDOMFactory(domFactory);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static SVGGeneratorContext createDefault(Document domFactory) {
/* 219 */     SVGGeneratorContext ctx = new SVGGeneratorContext(domFactory);
/* 220 */     ctx.setIDGenerator(new SVGIDGenerator());
/* 221 */     ctx.setExtensionHandler(new DefaultExtensionHandler());
/* 222 */     ctx.setImageHandler(new ImageHandlerBase64Encoder());
/* 223 */     ctx.setStyleHandler(new DefaultStyleHandler());
/* 224 */     ctx.setComment("Generated by the Batik Graphics2D SVG Generator");
/* 225 */     ctx.setErrorHandler(new DefaultErrorHandler());
/* 226 */     return ctx;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 234 */   public final GraphicContextDefaults getGraphicContextDefaults() { return this.gcDefaults; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 243 */   public final void setGraphicContextDefaults(GraphicContextDefaults gcDefaults) { this.gcDefaults = gcDefaults; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 251 */   public final SVGIDGenerator getIDGenerator() { return this.idGenerator; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final void setIDGenerator(SVGIDGenerator idGenerator) {
/* 259 */     if (idGenerator == null)
/* 260 */       throw new SVGGraphics2DRuntimeException("idGenerator should not be null"); 
/* 261 */     this.idGenerator = idGenerator;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 269 */   public final Document getDOMFactory() { return this.domFactory; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final void setDOMFactory(Document domFactory) {
/* 277 */     if (domFactory == null)
/* 278 */       throw new SVGGraphics2DRuntimeException("domFactory should not be null"); 
/* 279 */     this.domFactory = domFactory;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 287 */   public final ExtensionHandler getExtensionHandler() { return this.extensionHandler; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final void setExtensionHandler(ExtensionHandler extensionHandler) {
/* 295 */     if (extensionHandler == null)
/* 296 */       throw new SVGGraphics2DRuntimeException("extensionHandler should not be null"); 
/* 297 */     this.extensionHandler = extensionHandler;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 305 */   public final ImageHandler getImageHandler() { return this.imageHandler; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final void setImageHandler(ImageHandler imageHandler) {
/* 313 */     if (imageHandler == null)
/* 314 */       throw new SVGGraphics2DRuntimeException("imageHandler should not be null"); 
/* 315 */     this.imageHandler = imageHandler;
/* 316 */     this.genericImageHandler = new SimpleImageHandler(imageHandler);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final void setGenericImageHandler(GenericImageHandler genericImageHandler) {
/* 324 */     if (genericImageHandler == null) {
/* 325 */       throw new SVGGraphics2DRuntimeException("imageHandler should not be null");
/*     */     }
/* 327 */     this.imageHandler = null;
/* 328 */     this.genericImageHandler = genericImageHandler;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 336 */   public final StyleHandler getStyleHandler() { return this.styleHandler; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final void setStyleHandler(StyleHandler styleHandler) {
/* 344 */     if (styleHandler == null)
/* 345 */       throw new SVGGraphics2DRuntimeException("styleHandler should not be null"); 
/* 346 */     this.styleHandler = styleHandler;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 353 */   public final String getComment() { return this.generatorComment; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 361 */   public final void setComment(String generatorComment) { this.generatorComment = generatorComment; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 369 */   public final ErrorHandler getErrorHandler() { return this.errorHandler; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final void setErrorHandler(ErrorHandler errorHandler) {
/* 377 */     if (errorHandler == null)
/* 378 */       throw new SVGGraphics2DRuntimeException("errorHandler should not be null"); 
/* 379 */     this.errorHandler = errorHandler;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 387 */   public final boolean isEmbeddedFontsOn() { return this.svgFont; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 395 */   public final void setEmbeddedFontsOn(boolean svgFont) { this.svgFont = svgFont; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 402 */   public final int getPrecision() { return this.precision; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final void setPrecision(int precision) {
/* 412 */     if (precision < 0) {
/* 413 */       this.precision = 0;
/* 414 */     } else if (precision > 12) {
/* 415 */       this.precision = 12;
/*     */     } else {
/* 417 */       this.precision = precision;
/*     */     } 
/* 419 */     this.decimalFormat = decimalFormats[this.precision];
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public final String doubleString(double value) {
/* 427 */     double absvalue = Math.abs(value);
/*     */ 
/*     */     
/* 430 */     if (absvalue >= 1.0E8D || (int)value == value) {
/* 431 */       return Integer.toString((int)value);
/*     */     }
/*     */ 
/*     */     
/* 435 */     return this.decimalFormat.format(value);
/*     */   }
/*     */ 
/*     */   
/* 439 */   protected static DecimalFormatSymbols dsf = new DecimalFormatSymbols(Locale.US);
/*     */ 
/*     */   
/* 442 */   protected static DecimalFormat[] decimalFormats = new DecimalFormat[13];
/*     */   
/*     */   static  {
/* 445 */     decimalFormats[0] = new DecimalFormat("#", dsf);
/*     */     
/* 447 */     format = "#.";
/* 448 */     for (int i = 1; i < decimalFormats.length; i++) {
/* 449 */       format = format + "#";
/* 450 */       decimalFormats[i] = new DecimalFormat(format, dsf);
/*     */     } 
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svggen.jar!\org\apache\batik\svggen\SVGGeneratorContext.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */