/*     */ package org.apache.batik.svggen;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.OutputStreamWriter;
/*     */ import java.io.Writer;
/*     */ import org.apache.batik.util.SVGConstants;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.CDATASection;
/*     */ import org.w3c.dom.Comment;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.NamedNodeMap;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.NodeList;
/*     */ import org.w3c.dom.Text;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ class XmlWriter
/*     */   implements SVGConstants
/*     */ {
/*     */   private static String EOL;
/*     */   private static final String TAG_END = "/>";
/*     */   private static final String TAG_START = "</";
/*     */   private static final char[] SPACES = { 
/*  53 */       ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ' };
/*     */ 
/*     */   
/*  56 */   private static final int SPACES_LEN = SPACES.length;
/*     */   
/*     */   static  {
/*     */     
/*  60 */     try { temp = System.getProperty("line.separator", "\n"); }
/*  61 */     catch (SecurityException e) { temp = "\n"; }
/*  62 */      EOL = temp;
/*     */   }
/*     */   
/*     */   static class IndentWriter extends Writer {
/*     */     protected Writer proxied;
/*     */     protected int indentLevel;
/*     */     protected int column;
/*     */     
/*     */     public IndentWriter(Writer proxied) {
/*  71 */       if (proxied == null) {
/*  72 */         throw new SVGGraphics2DRuntimeException("proxy should not be null");
/*     */       }
/*     */       
/*  75 */       this.proxied = proxied;
/*     */     }
/*     */ 
/*     */     
/*  79 */     public void setIndentLevel(int indentLevel) { this.indentLevel = indentLevel; }
/*     */ 
/*     */ 
/*     */     
/*  83 */     public int getIndentLevel() { return this.indentLevel; }
/*     */ 
/*     */     
/*     */     public void printIndent() {
/*  87 */       this.proxied.write(EOL);
/*  88 */       int temp = this.indentLevel;
/*  89 */       while (temp > 0) {
/*  90 */         if (temp > SPACES_LEN) {
/*  91 */           this.proxied.write(SPACES, 0, SPACES_LEN);
/*  92 */           temp -= SPACES_LEN; continue;
/*     */         } 
/*  94 */         this.proxied.write(SPACES, 0, temp);
/*     */         
/*     */         break;
/*     */       } 
/*  98 */       this.column = this.indentLevel;
/*     */     }
/*     */ 
/*     */     
/* 102 */     public Writer getProxied() { return this.proxied; }
/*     */ 
/*     */     
/* 105 */     public int getColumn() { return this.column; }
/*     */     
/*     */     public void write(int c) {
/* 108 */       this.column++;
/* 109 */       this.proxied.write(c);
/*     */     }
/*     */     
/*     */     public void write(char[] cbuf) throws IOException {
/* 113 */       this.column += cbuf.length;
/* 114 */       this.proxied.write(cbuf);
/*     */     }
/*     */     
/*     */     public void write(char[] cbuf, int off, int len) throws IOException {
/* 118 */       this.column += len;
/* 119 */       this.proxied.write(cbuf, off, len);
/*     */     }
/*     */     
/*     */     public void write(String str) throws IOException {
/* 123 */       this.column += str.length();
/* 124 */       this.proxied.write(str);
/*     */     }
/*     */     
/*     */     public void write(String str, int off, int len) throws IOException {
/* 128 */       this.column += len;
/* 129 */       this.proxied.write(str, off, len);
/*     */     }
/*     */ 
/*     */     
/* 133 */     public void flush() { this.proxied.flush(); }
/*     */ 
/*     */     
/*     */     public void close() {
/* 137 */       this.column = -1;
/* 138 */       this.proxied.close();
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static void writeXml(Attr attr, IndentWriter out, boolean escaped) throws IOException {
/* 145 */     String name = attr.getName();
/* 146 */     out.write(name);
/* 147 */     out.write("=\"");
/* 148 */     writeChildrenXml(attr, out, escaped);
/* 149 */     out.write(34);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void writeChildrenXml(Attr attr, IndentWriter out, boolean escaped) throws IOException {
/* 158 */     char[] data = attr.getValue().toCharArray();
/* 159 */     if (data == null)
/*     */       return; 
/* 161 */     int length = data.length;
/* 162 */     int start = 0, last = 0;
/* 163 */     while (last < length) {
/* 164 */       char c = data[last];
/* 165 */       switch (c) {
/*     */         case '<':
/* 167 */           out.write(data, start, last - start);
/* 168 */           start = last + 1;
/* 169 */           out.write("&lt;");
/*     */           break;
/*     */         case '>':
/* 172 */           out.write(data, start, last - start);
/* 173 */           start = last + 1;
/* 174 */           out.write("&gt;");
/*     */           break;
/*     */         case '&':
/* 177 */           out.write(data, start, last - start);
/* 178 */           start = last + 1;
/* 179 */           out.write("&amp;");
/*     */           break;
/*     */         case '\'':
/* 182 */           out.write(data, start, last - start);
/* 183 */           start = last + 1;
/* 184 */           out.write("&apos;");
/*     */           break;
/*     */         case '"':
/* 187 */           out.write(data, start, last - start);
/* 188 */           start = last + 1;
/* 189 */           out.write("&quot;");
/*     */           break;
/*     */         default:
/* 192 */           if (escaped && c > '') {
/* 193 */             out.write(data, start, last - start);
/* 194 */             String hex = "0000" + Integer.toHexString(c);
/* 195 */             out.write("&#x" + hex.substring(hex.length() - 4) + ";");
/* 196 */             start = last + 1;
/*     */           } 
/*     */           break;
/*     */       } 
/* 200 */       last++;
/*     */     } 
/* 202 */     out.write(data, start, last - start);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void writeXml(Comment comment, IndentWriter out, boolean escaped) throws IOException {
/* 214 */     char[] data = comment.getData().toCharArray();
/*     */     
/* 216 */     if (data == null) {
/* 217 */       out.write("<!---->");
/*     */       
/*     */       return;
/*     */     } 
/* 221 */     out.write("<!--");
/* 222 */     boolean sawDash = false;
/* 223 */     int length = data.length;
/* 224 */     int start = 0, last = 0;
/*     */ 
/*     */     
/* 227 */     while (last < length) {
/* 228 */       char c = data[last];
/* 229 */       if (c == '-') {
/* 230 */         if (sawDash) {
/* 231 */           out.write(data, start, last - start);
/* 232 */           start = last;
/* 233 */           out.write(32);
/*     */         } 
/* 235 */         sawDash = true;
/*     */       } else {
/* 237 */         sawDash = false;
/*     */       } 
/* 239 */       last++;
/*     */     } 
/* 241 */     out.write(data, start, last - start);
/* 242 */     if (sawDash)
/* 243 */       out.write(32); 
/* 244 */     out.write("-->");
/*     */   }
/*     */ 
/*     */ 
/*     */   
/* 249 */   private static void writeXml(Text text, IndentWriter out, boolean escaped) throws IOException { writeXml(text, out, false, escaped); }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static void writeXml(Text text, IndentWriter out, boolean trimWS, boolean escaped) throws IOException {
/* 255 */     char[] data = text.getData().toCharArray();
/*     */ 
/*     */     
/* 258 */     if (data == null) {
/* 259 */       System.err.println("Null text data??"); return;
/*     */     } 
/* 261 */     int length = data.length;
/* 262 */     int start = 0, last = 0;
/* 263 */     if (trimWS) {
/* 264 */       while (last < length) {
/* 265 */         char c = data[last];
/* 266 */         switch (c) { case '\t': case '\n': case '\r': case ' ':
/* 267 */             last++;
/*     */             continue; }
/*     */         
/*     */         break;
/*     */       } 
/* 272 */       start = last;
/*     */     } 
/*     */     
/* 275 */     while (last < length) {
/* 276 */       char c = data[last];
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 286 */       switch (c) { case '\t': case '\n': case '\r':
/*     */         case ' ':
/* 288 */           if (trimWS) {
/* 289 */             int wsStart = last; last++;
/* 290 */             while (last < length) {
/* 291 */               switch (data[last]) { case '\t': case '\n': case '\r':
/*     */                 case ' ':
/* 293 */                   last++;
/*     */                   continue; }
/*     */               
/*     */               break;
/*     */             } 
/* 298 */             if (last == length) {
/* 299 */               out.write(data, start, wsStart - start);
/*     */               return;
/*     */             } 
/*     */             continue;
/*     */           } 
/*     */           break;
/*     */         
/*     */         case '<':
/* 307 */           out.write(data, start, last - start);
/* 308 */           start = last + 1;
/* 309 */           out.write("&lt;");
/*     */           break;
/*     */         case '>':
/* 312 */           out.write(data, start, last - start);
/* 313 */           start = last + 1;
/* 314 */           out.write("&gt;");
/*     */           break;
/*     */         case '&':
/* 317 */           out.write(data, start, last - start);
/* 318 */           start = last + 1;
/* 319 */           out.write("&amp;");
/*     */           break;
/*     */         default:
/* 322 */           if (escaped && c > '') {
/* 323 */             out.write(data, start, last - start);
/* 324 */             String hex = "0000" + Integer.toHexString(c);
/* 325 */             out.write("&#x" + hex.substring(hex.length() - 4) + ";");
/* 326 */             start = last + 1;
/*     */           } 
/*     */           break; }
/*     */       
/* 330 */       last++;
/*     */     } 
/* 332 */     out.write(data, start, last - start);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static void writeXml(CDATASection cdataSection, IndentWriter out, boolean escaped) throws IOException {
/* 338 */     char[] data = cdataSection.getData().toCharArray();
/* 339 */     if (data == null) {
/* 340 */       out.write("<![CDATA[]]>");
/*     */       
/*     */       return;
/*     */     } 
/* 344 */     out.write("<![CDATA[");
/* 345 */     int length = data.length;
/* 346 */     int start = 0, last = 0;
/* 347 */     while (last < length) {
/* 348 */       char c = data[last];
/*     */ 
/*     */ 
/*     */       
/* 352 */       if (c == ']' && 
/* 353 */         last + 2 < data.length && data[last + 1] == ']' && data[last + 2] == '>') {
/*     */ 
/*     */         
/* 356 */         out.write(data, start, last - start);
/* 357 */         start = last + 1;
/* 358 */         out.write("]]]]><![CDATA[>");
/*     */         
/*     */         continue;
/*     */       } 
/* 362 */       last++;
/*     */     } 
/* 364 */     out.write(data, start, last - start);
/* 365 */     out.write("]]>");
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static void writeXml(Element element, IndentWriter out, boolean escaped) throws IOException, SVGGraphics2DIOException {
/* 371 */     out.write("</", 0, 1);
/* 372 */     out.write(element.getTagName());
/*     */     
/* 374 */     NamedNodeMap attributes = element.getAttributes();
/* 375 */     if (attributes != null) {
/* 376 */       int nAttr = attributes.getLength();
/* 377 */       for (int i = 0; i < nAttr; i++) {
/* 378 */         Attr attr = (Attr)attributes.item(i);
/* 379 */         out.write(32);
/* 380 */         writeXml(attr, out, escaped);
/*     */       } 
/*     */     } 
/*     */     
/* 384 */     boolean lastElem = (element.getParentNode().getLastChild() == element);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 391 */     if (!element.hasChildNodes()) {
/* 392 */       if (lastElem)
/* 393 */         out.setIndentLevel(out.getIndentLevel() - 2); 
/* 394 */       out.printIndent();
/* 395 */       out.write("/>", 0, 2);
/*     */       return;
/*     */     } 
/* 398 */     Node child = element.getFirstChild();
/* 399 */     out.printIndent();
/* 400 */     out.write("/>", 1, 1);
/* 401 */     if (child.getNodeType() != 3 || element.getLastChild() != child)
/*     */     {
/* 403 */       out.setIndentLevel(out.getIndentLevel() + 2);
/*     */     }
/*     */     
/* 406 */     writeChildrenXml(element, out, escaped);
/*     */     
/* 408 */     out.write("</", 0, 2);
/* 409 */     out.write(element.getTagName());
/* 410 */     if (lastElem)
/* 411 */       out.setIndentLevel(out.getIndentLevel() - 2); 
/* 412 */     out.printIndent();
/* 413 */     out.write("/>", 1, 1);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static void writeChildrenXml(Element element, IndentWriter out, boolean escaped) throws IOException, SVGGraphics2DIOException {
/* 419 */     Node child = element.getFirstChild();
/* 420 */     while (child != null) {
/* 421 */       writeXml(child, out, escaped);
/* 422 */       child = child.getNextSibling();
/*     */     } 
/*     */   }
/*     */ 
/*     */   
/*     */   private static void writeDocumentHeader(IndentWriter out) throws IOException {
/* 428 */     String encoding = null;
/*     */     
/* 430 */     if (out.getProxied() instanceof OutputStreamWriter) {
/* 431 */       OutputStreamWriter osw = (OutputStreamWriter)out.getProxied();
/* 432 */       encoding = java2std(osw.getEncoding());
/*     */     } 
/*     */     
/* 435 */     out.write("<?xml version=\"1.0\"");
/* 436 */     if (encoding != null) {
/* 437 */       out.write(" encoding=\"");
/* 438 */       out.write(encoding);
/* 439 */       out.write(34);
/*     */     } 
/* 441 */     out.write("?>");
/* 442 */     out.write(EOL);
/*     */ 
/*     */     
/* 445 */     out.write("<!DOCTYPE svg PUBLIC '");
/* 446 */     out.write("-//W3C//DTD SVG 1.0//EN");
/* 447 */     out.write("'"); out.write(EOL);
/*     */     
/* 449 */     out.write("          '");
/* 450 */     out.write("http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd");
/* 451 */     out.write("'"); out.write(">"); out.write(EOL);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static void writeXml(Document document, IndentWriter out, boolean escaped) throws IOException, SVGGraphics2DIOException {
/* 457 */     writeDocumentHeader(out);
/* 458 */     NodeList childList = document.getChildNodes();
/* 459 */     writeXml(childList, out, escaped);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   private static void writeXml(NodeList childList, IndentWriter out, boolean escaped) throws IOException, SVGGraphics2DIOException {
/* 465 */     int length = childList.getLength();
/*     */     
/* 467 */     if (length == 0)
/*     */       return; 
/* 469 */     for (int i = 0; i < length; i++) {
/* 470 */       Node child = childList.item(i);
/* 471 */       writeXml(child, out, escaped);
/* 472 */       out.write(EOL);
/*     */     } 
/*     */   }
/*     */   
/*     */   static String java2std(String encodingName) {
/* 477 */     if (encodingName == null) {
/* 478 */       return null;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 485 */     if (encodingName.startsWith("ISO8859_"))
/* 486 */       return "ISO-8859-" + encodingName.substring(8); 
/* 487 */     if (encodingName.startsWith("8859_")) {
/* 488 */       return "ISO-8859-" + encodingName.substring(5);
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 493 */     if ("ASCII7".equalsIgnoreCase(encodingName) || "ASCII".equalsIgnoreCase(encodingName))
/*     */     {
/* 495 */       return "US-ASCII";
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 501 */     if ("UTF8".equalsIgnoreCase(encodingName))
/* 502 */       return "UTF-8"; 
/* 503 */     if (encodingName.startsWith("Unicode")) {
/* 504 */       return "UTF-16";
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 509 */     if ("SJIS".equalsIgnoreCase(encodingName))
/* 510 */       return "Shift_JIS"; 
/* 511 */     if ("JIS".equalsIgnoreCase(encodingName))
/* 512 */       return "ISO-2022-JP"; 
/* 513 */     if ("EUCJIS".equalsIgnoreCase(encodingName)) {
/* 514 */       return "EUC-JP";
/*     */     }
/*     */     
/* 517 */     return "UTF-8";
/*     */   }
/*     */   
/*     */   public static void writeXml(Node node, Writer writer, boolean escaped) throws SVGGraphics2DIOException {
/*     */     try {
/*     */       NodeList childList;
/* 523 */       IndentWriter out = null;
/* 524 */       if (writer instanceof IndentWriter) {
/* 525 */         out = (IndentWriter)writer;
/*     */       } else {
/* 527 */         out = new IndentWriter(writer);
/*     */       } 
/* 529 */       switch (node.getNodeType()) {
/*     */         case 2:
/* 531 */           writeXml((Attr)node, out, escaped);
/*     */           return;
/*     */         case 8:
/* 534 */           writeXml((Comment)node, out, escaped);
/*     */           return;
/*     */         case 3:
/* 537 */           writeXml((Text)node, out, escaped);
/*     */           return;
/*     */         case 4:
/* 540 */           writeXml((CDATASection)node, out, escaped);
/*     */           return;
/*     */         case 9:
/* 543 */           writeXml((Document)node, out, escaped);
/*     */           return;
/*     */         case 11:
/* 546 */           writeDocumentHeader(out);
/* 547 */           childList = node.getChildNodes();
/* 548 */           writeXml(childList, out, escaped);
/*     */           return;
/*     */         case 1:
/* 551 */           writeXml((Element)node, out, escaped);
/*     */           return;
/*     */       } 
/* 554 */       throw new SVGGraphics2DRuntimeException("Unable to write node of type " + node.getClass().getName());
/*     */     }
/*     */     catch (IOException io) {
/*     */       
/* 558 */       throw new SVGGraphics2DIOException(io);
/*     */     } 
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svggen.jar!\org\apache\batik\svggen\XmlWriter.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */