/*     */ package org.apache.batik.svggen.font;
/*     */ 
/*     */ import java.io.FileOutputStream;
/*     */ import java.io.PrintStream;
/*     */ import org.apache.batik.svggen.font.table.CmapFormat;
/*     */ import org.apache.batik.svggen.font.table.Feature;
/*     */ import org.apache.batik.svggen.font.table.FeatureTags;
/*     */ import org.apache.batik.svggen.font.table.GsubTable;
/*     */ import org.apache.batik.svggen.font.table.KernSubtable;
/*     */ import org.apache.batik.svggen.font.table.KernTable;
/*     */ import org.apache.batik.svggen.font.table.KerningPair;
/*     */ import org.apache.batik.svggen.font.table.LangSys;
/*     */ import org.apache.batik.svggen.font.table.PostTable;
/*     */ import org.apache.batik.svggen.font.table.Script;
/*     */ import org.apache.batik.svggen.font.table.ScriptTags;
/*     */ import org.apache.batik.svggen.font.table.SingleSubst;
/*     */ import org.apache.batik.util.SVGConstants;
/*     */ import org.apache.batik.util.XMLConstants;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGFont
/*     */   implements XMLConstants, SVGConstants, ScriptTags, FeatureTags
/*     */ {
/*     */   static final String EOL;
/*     */   static final String PROPERTY_LINE_SEPARATOR = "line.separator";
/*     */   static final String PROPERTY_LINE_SEPARATOR_DEFAULT = "\n";
/*     */   static final int DEFAULT_FIRST = 32;
/*     */   static final int DEFAULT_LAST = 128;
/*     */   private static String QUOT_EOL;
/*     */   private static String CONFIG_USAGE;
/*     */   private static String CONFIG_SVG_BEGIN;
/*     */   private static String CONFIG_SVG_TEST_CARD_START;
/*     */   private static String CONFIG_SVG_TEST_CARD_END;
/*     */   public static final char ARG_KEY_START_CHAR = '-';
/*     */   public static final String ARG_KEY_CHAR_RANGE_LOW = "-l";
/*     */   public static final String ARG_KEY_CHAR_RANGE_HIGH = "-h";
/*     */   public static final String ARG_KEY_ID = "-id";
/*     */   public static final String ARG_KEY_ASCII = "-ascii";
/*     */   public static final String ARG_KEY_TESTCARD = "-testcard";
/*     */   public static final String ARG_KEY_AUTO_RANGE = "-autorange";
/*     */   public static final String ARG_KEY_OUTPUT_PATH = "-o";
/*     */   
/*     */   static  {
/*     */     try {
/*  59 */       temp = System.getProperty("line.separator", "\n");
/*     */     } catch (SecurityException e) {
/*     */       
/*  62 */       temp = "\n";
/*     */     } 
/*  64 */     EOL = temp;
/*     */ 
/*     */     
/*  67 */     QUOT_EOL = '"' + EOL;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  72 */     CONFIG_USAGE = "SVGFont.config.usage";
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  80 */     CONFIG_SVG_BEGIN = "SVGFont.config.svg.begin";
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  87 */     CONFIG_SVG_TEST_CARD_START = "SVGFont.config.svg.test.card.start";
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  94 */     CONFIG_SVG_TEST_CARD_END = "SVGFont.config.svg.test.card.end";
/*     */   }
/*     */   
/*     */   protected static String encodeEntities(String s) {
/*  98 */     StringBuffer sb = new StringBuffer();
/*  99 */     for (int i = 0; i < s.length(); i++) {
/* 100 */       if (s.charAt(i) == '<') {
/* 101 */         sb.append("&lt;");
/* 102 */       } else if (s.charAt(i) == '>') {
/* 103 */         sb.append("&gt;");
/* 104 */       } else if (s.charAt(i) == '&') {
/* 105 */         sb.append("&amp;");
/* 106 */       } else if (s.charAt(i) == '\'') {
/* 107 */         sb.append("&apos;");
/* 108 */       } else if (s.charAt(i) == '"') {
/* 109 */         sb.append("&quot;");
/*     */       } else {
/* 111 */         sb.append(s.charAt(i));
/*     */       } 
/*     */     } 
/* 114 */     return sb.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*     */   protected static String getContourAsSVGPathData(Glyph glyph, int startIndex, int count) {
/* 120 */     if ((glyph.getPoint(startIndex)).endOfContour) {
/* 121 */       return "";
/*     */     }
/*     */     
/* 124 */     StringBuffer sb = new StringBuffer();
/* 125 */     int offset = 0;
/*     */     
/* 127 */     while (offset < count) {
/* 128 */       Point point = glyph.getPoint(startIndex + offset % count);
/* 129 */       Point point_plus1 = glyph.getPoint(startIndex + (offset + 1) % count);
/* 130 */       Point point_plus2 = glyph.getPoint(startIndex + (offset + 2) % count);
/*     */       
/* 132 */       if (offset == 0) {
/* 133 */         sb.append("M").append(String.valueOf(point.x)).append(" ").append(String.valueOf(point.y));
/*     */       }
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 139 */       if (point.onCurve && point_plus1.onCurve) {
/* 140 */         if (point_plus1.x == point.x) {
/* 141 */           sb.append("V").append(String.valueOf(point_plus1.y));
/*     */         }
/* 143 */         else if (point_plus1.y == point.y) {
/* 144 */           sb.append("H").append(String.valueOf(point_plus1.x));
/*     */         } else {
/*     */           
/* 147 */           sb.append("L").append(String.valueOf(point_plus1.x)).append(" ").append(String.valueOf(point_plus1.y));
/*     */         } 
/*     */ 
/*     */ 
/*     */         
/* 152 */         offset++; continue;
/* 153 */       }  if (point.onCurve && !point_plus1.onCurve && point_plus2.onCurve) {
/*     */         
/* 155 */         sb.append("Q").append(String.valueOf(point_plus1.x)).append(" ").append(String.valueOf(point_plus1.y)).append(" ").append(String.valueOf(point_plus2.x)).append(" ").append(String.valueOf(point_plus2.y));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 163 */         offset += 2; continue;
/* 164 */       }  if (point.onCurve && !point_plus1.onCurve && !point_plus2.onCurve) {
/*     */         
/* 166 */         sb.append("Q").append(String.valueOf(point_plus1.x)).append(" ").append(String.valueOf(point_plus1.y)).append(" ").append(String.valueOf(midValue(point_plus1.x, point_plus2.x))).append(" ").append(String.valueOf(midValue(point_plus1.y, point_plus2.y)));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 174 */         offset += 2; continue;
/* 175 */       }  if (!point.onCurve && !point_plus1.onCurve) {
/*     */         
/* 177 */         sb.append("T").append(String.valueOf(midValue(point.x, point_plus1.x))).append(" ").append(String.valueOf(midValue(point.y, point_plus1.y)));
/*     */ 
/*     */ 
/*     */         
/* 181 */         offset++; continue;
/* 182 */       }  if (!point.onCurve && point_plus1.onCurve) {
/* 183 */         sb.append("T").append(String.valueOf(point_plus1.x)).append(" ").append(String.valueOf(point_plus1.y));
/*     */ 
/*     */ 
/*     */         
/* 187 */         offset++; continue;
/*     */       } 
/* 189 */       System.out.println("drawGlyph case not catered for!!");
/*     */       
/*     */       break;
/*     */     } 
/* 193 */     sb.append("Z");
/*     */     
/* 195 */     return sb.toString();
/*     */   }
/*     */   
/*     */   protected static String getSVGFontFaceElement(Font font) {
/* 199 */     StringBuffer sb = new StringBuffer();
/* 200 */     String fontFamily = font.getNameTable().getRecord((short)1);
/* 201 */     short unitsPerEm = font.getHeadTable().getUnitsPerEm();
/* 202 */     String panose = font.getOS2Table().getPanose().toString();
/* 203 */     short ascent = font.getHheaTable().getAscender();
/* 204 */     short descent = font.getHheaTable().getDescender();
/* 205 */     int baseline = 0;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 244 */     sb.append("<").append("font-face").append(EOL).append("    ").append("font-family").append("=\"").append(fontFamily).append(QUOT_EOL).append("    ").append("units-per-em").append("=\"").append(unitsPerEm).append(QUOT_EOL).append("    ").append("panose-1").append("=\"").append(panose).append(QUOT_EOL).append("    ").append("ascent").append("=\"").append(ascent).append(QUOT_EOL).append("    ").append("descent").append("=\"").append(descent).append(QUOT_EOL).append("    ").append("alphabetic").append("=\"").append(baseline).append('"').append(" />").append(EOL);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 259 */     return sb.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static void writeFontAsSVGFragment(PrintStream ps, Font font, String id, int first, int last, boolean autoRange, boolean forceAscii) throws Exception {
/* 277 */     int horiz_advance_x = font.getOS2Table().getAvgCharWidth();
/*     */     
/* 279 */     ps.print("<");
/* 280 */     ps.print("font");
/* 281 */     ps.print(" ");
/*     */     
/* 283 */     if (id != null) {
/* 284 */       ps.print("id");
/* 285 */       ps.print("=\"");
/*     */       
/* 287 */       ps.print(id);
/* 288 */       ps.print('"');
/* 289 */       ps.print(" ");
/*     */     } 
/*     */ 
/*     */     
/* 293 */     ps.print("horiz-adv-x");
/* 294 */     ps.print("=\"");
/*     */     
/* 296 */     ps.print(horiz_advance_x);
/* 297 */     ps.print('"');
/* 298 */     ps.print(" >");
/*     */ 
/*     */     
/* 301 */     ps.print(getSVGFontFaceElement(font));
/*     */ 
/*     */     
/* 304 */     CmapFormat cmapFmt = null;
/* 305 */     if (forceAscii) {
/*     */       
/* 307 */       cmapFmt = font.getCmapTable().getCmapFormat((short)1, (short)0);
/*     */     
/*     */     }
/*     */     else {
/*     */       
/* 312 */       cmapFmt = font.getCmapTable().getCmapFormat((short)3, (short)1);
/*     */ 
/*     */       
/* 315 */       if (cmapFmt == null)
/*     */       {
/* 317 */         cmapFmt = font.getCmapTable().getCmapFormat((short)3, (short)0);
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 322 */     if (cmapFmt == null) {
/* 323 */       throw new Exception("Cannot find a suitable cmap table");
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 329 */     GsubTable gsub = (GsubTable)font.getTable(1196643650);
/* 330 */     SingleSubst initialSubst = null;
/* 331 */     SingleSubst medialSubst = null;
/* 332 */     SingleSubst terminalSubst = null;
/* 333 */     if (gsub != null) {
/* 334 */       Script s = gsub.getScriptList().findScript("arab");
/* 335 */       if (s != null) {
/* 336 */         LangSys ls = s.getDefaultLangSys();
/* 337 */         if (ls != null) {
/* 338 */           Feature init = gsub.getFeatureList().findFeature(ls, "init");
/* 339 */           Feature medi = gsub.getFeatureList().findFeature(ls, "medi");
/* 340 */           Feature fina = gsub.getFeatureList().findFeature(ls, "fina");
/*     */           
/* 342 */           initialSubst = (SingleSubst)gsub.getLookupList().getLookup(init, 0).getSubtable(0);
/*     */           
/* 344 */           medialSubst = (SingleSubst)gsub.getLookupList().getLookup(medi, 0).getSubtable(0);
/*     */           
/* 346 */           terminalSubst = (SingleSubst)gsub.getLookupList().getLookup(fina, 0).getSubtable(0);
/*     */         } 
/*     */       } 
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 353 */     ps.println(getGlyphAsSVG(font, font.getGlyph(0), 0, horiz_advance_x, initialSubst, medialSubst, terminalSubst, ""));
/*     */ 
/*     */     
/*     */     try {
/* 357 */       if (first == -1)
/* 358 */         if (!autoRange) { first = 32; }
/* 359 */         else { first = cmapFmt.getFirst(); }
/*     */          
/* 361 */       if (last == -1) {
/* 362 */         if (!autoRange) { last = 128; }
/* 363 */         else { last = cmapFmt.getLast(); }
/*     */       
/*     */       }
/*     */       
/* 367 */       for (int i = first; i <= last; i++) {
/* 368 */         int glyphIndex = cmapFmt.mapCharCode(i);
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 373 */         if (glyphIndex > 0) {
/* 374 */           ps.println(getGlyphAsSVG(font, font.getGlyph(glyphIndex), glyphIndex, horiz_advance_x, initialSubst, medialSubst, terminalSubst, (32 <= i && i <= 127) ? encodeEntities(String.valueOf((char)i)) : ("&#x" + Integer.toHexString(i) + ";")));
/*     */         }
/*     */       } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 388 */       KernTable kern = (KernTable)font.getTable(1801810542);
/* 389 */       if (kern != null) {
/* 390 */         KernSubtable kst = kern.getSubtable(0);
/* 391 */         PostTable post = (PostTable)font.getTable(1886352244);
/* 392 */         for (int i = 0; i < kst.getKerningPairCount(); i++) {
/* 393 */           ps.println(getKerningPairAsSVG(kst.getKerningPair(i), post));
/*     */         }
/*     */       } 
/*     */     } catch (Exception e) {
/* 397 */       System.err.println(e.getMessage());
/*     */     } 
/*     */     
/* 400 */     ps.print("</");
/* 401 */     ps.print("font");
/* 402 */     ps.println(">");
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static String getGlyphAsSVG(Font font, Glyph glyph, int glyphIndex, int defaultHorizAdvanceX, String attrib, String code) {
/* 414 */     StringBuffer sb = new StringBuffer();
/* 415 */     int firstIndex = 0;
/* 416 */     int count = 0;
/*     */ 
/*     */ 
/*     */     
/* 420 */     int horiz_advance_x = font.getHmtxTable().getAdvanceWidth(glyphIndex);
/*     */     
/* 422 */     if (glyphIndex == 0) {
/* 423 */       sb.append("<");
/* 424 */       sb.append("missing-glyph");
/*     */     
/*     */     }
/*     */     else {
/*     */       
/* 429 */       sb.append("<").append("glyph").append(" ").append("unicode").append("=\"").append(code).append('"');
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 435 */       sb.append(" ").append("glyph-name").append("=\"").append(font.getPostTable().getGlyphName(glyphIndex)).append('"');
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 441 */     if (horiz_advance_x != defaultHorizAdvanceX) {
/* 442 */       sb.append(" ").append("horiz-adv-x").append("=\"").append(horiz_advance_x).append('"');
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 447 */     if (attrib != null) {
/* 448 */       sb.append(attrib);
/*     */     }
/*     */     
/* 451 */     if (glyph != null) {
/*     */       
/* 453 */       sb.append(" ").append("d").append("=\"");
/* 454 */       for (int i = 0; i < glyph.getPointCount(); i++) {
/* 455 */         count++;
/* 456 */         if ((glyph.getPoint(i)).endOfContour) {
/* 457 */           sb.append(getContourAsSVGPathData(glyph, firstIndex, count));
/* 458 */           firstIndex = i + 1;
/* 459 */           count = 0;
/*     */         } 
/*     */       } 
/*     */       
/* 463 */       sb.append('"');
/*     */     } 
/*     */     
/* 466 */     sb.append(" />");
/*     */ 
/*     */ 
/*     */     
/* 470 */     chopUpStringBuffer(sb);
/*     */     
/* 472 */     return sb.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static String getGlyphAsSVG(Font font, Glyph glyph, int glyphIndex, int defaultHorizAdvanceX, SingleSubst arabInitSubst, SingleSubst arabMediSubst, SingleSubst arabTermSubst, String code) {
/* 485 */     StringBuffer sb = new StringBuffer();
/* 486 */     boolean substituted = false;
/*     */ 
/*     */     
/* 489 */     int arabInitGlyphIndex = glyphIndex;
/* 490 */     int arabMediGlyphIndex = glyphIndex;
/* 491 */     int arabTermGlyphIndex = glyphIndex;
/* 492 */     if (arabInitSubst != null) {
/* 493 */       arabInitGlyphIndex = arabInitSubst.substitute(glyphIndex);
/*     */     }
/* 495 */     if (arabMediSubst != null) {
/* 496 */       arabMediGlyphIndex = arabMediSubst.substitute(glyphIndex);
/*     */     }
/* 498 */     if (arabTermSubst != null) {
/* 499 */       arabTermGlyphIndex = arabTermSubst.substitute(glyphIndex);
/*     */     }
/*     */     
/* 502 */     if (arabInitGlyphIndex != glyphIndex) {
/* 503 */       sb.append(getGlyphAsSVG(font, font.getGlyph(arabInitGlyphIndex), arabInitGlyphIndex, defaultHorizAdvanceX, " arabic-form=\"initial\"", code));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 513 */       sb.append(EOL);
/* 514 */       substituted = true;
/*     */     } 
/*     */     
/* 517 */     if (arabMediGlyphIndex != glyphIndex) {
/* 518 */       sb.append(getGlyphAsSVG(font, font.getGlyph(arabMediGlyphIndex), arabMediGlyphIndex, defaultHorizAdvanceX, " arabic-form=\"medial\"", code));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 528 */       sb.append(EOL);
/* 529 */       substituted = true;
/*     */     } 
/*     */     
/* 532 */     if (arabTermGlyphIndex != glyphIndex) {
/* 533 */       sb.append(getGlyphAsSVG(font, font.getGlyph(arabTermGlyphIndex), arabTermGlyphIndex, defaultHorizAdvanceX, " arabic-form=\"terminal\"", code));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 543 */       sb.append(EOL);
/* 544 */       substituted = true;
/*     */     } 
/*     */     
/* 547 */     if (substituted) {
/* 548 */       sb.append(getGlyphAsSVG(font, glyph, glyphIndex, defaultHorizAdvanceX, " arabic-form=\"isolated\"", code));
/*     */ 
/*     */ 
/*     */     
/*     */     }
/*     */     else {
/*     */ 
/*     */ 
/*     */ 
/*     */       
/* 558 */       sb.append(getGlyphAsSVG(font, glyph, glyphIndex, defaultHorizAdvanceX, null, code));
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 567 */     return sb.toString();
/*     */   }
/*     */   
/*     */   protected static String getKerningPairAsSVG(KerningPair kp, PostTable post) {
/* 571 */     StringBuffer sb = new StringBuffer();
/*     */     
/* 573 */     sb.append("<").append("hkern").append(" ");
/* 574 */     sb.append("g1").append("=\"");
/*     */     
/* 576 */     sb.append(post.getGlyphName(kp.getLeft()));
/*     */     
/* 578 */     sb.append('"').append(" ").append("g2").append("=\"");
/*     */     
/* 580 */     sb.append(post.getGlyphName(kp.getRight()));
/*     */     
/* 582 */     sb.append('"').append(" ").append("k").append("=\"");
/*     */ 
/*     */     
/* 585 */     sb.append(-kp.getValue());
/*     */     
/* 587 */     sb.append('"').append(" />");
/*     */     
/* 589 */     return sb.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 627 */   protected static void writeSvgBegin(PrintStream ps) { ps.println(Messages.formatMessage(CONFIG_SVG_BEGIN, new Object[] { "-//W3C//DTD SVG 1.0//EN", "http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd" })); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 634 */   protected static void writeSvgDefsBegin(PrintStream ps) { ps.println("<defs >"); }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 639 */   protected static void writeSvgDefsEnd(PrintStream ps) { ps.println("</defs>"); }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 644 */   protected static void writeSvgEnd(PrintStream ps) { ps.println("</svg>"); }
/*     */ 
/*     */   
/*     */   protected static void writeSvgTestCard(PrintStream ps, String fontFamily) {
/* 648 */     ps.println(Messages.formatMessage(CONFIG_SVG_TEST_CARD_START, null));
/* 649 */     ps.println(fontFamily);
/* 650 */     ps.println(Messages.formatMessage(CONFIG_SVG_TEST_CARD_END, null));
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void main(String[] args) {
/*     */     try {
/* 678 */       String path = parseArgs(args, null);
/* 679 */       String low = parseArgs(args, "-l");
/* 680 */       String high = parseArgs(args, "-h");
/* 681 */       String id = parseArgs(args, "-id");
/* 682 */       String ascii = parseArgs(args, "-ascii");
/* 683 */       String testCard = parseArgs(args, "-testcard");
/* 684 */       String outPath = parseArgs(args, "-o");
/* 685 */       String autoRange = parseArgs(args, "-autorange");
/* 686 */       PrintStream ps = null;
/* 687 */       FileOutputStream fos = null;
/*     */ 
/*     */       
/* 690 */       if (outPath != null) {
/*     */         
/* 692 */         fos = new FileOutputStream(outPath);
/* 693 */         ps = new PrintStream(fos);
/*     */       } else {
/*     */         
/* 696 */         ps = System.out;
/*     */       } 
/*     */ 
/*     */       
/* 700 */       if (path != null) {
/* 701 */         Font font = Font.create(path);
/*     */ 
/*     */         
/* 704 */         writeSvgBegin(ps);
/* 705 */         writeSvgDefsBegin(ps);
/* 706 */         writeFontAsSVGFragment(ps, font, id, (low != null) ? Integer.parseInt(low) : -1, (high != null) ? Integer.parseInt(high) : -1, (autoRange != null), (ascii != null));
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */         
/* 714 */         writeSvgDefsEnd(ps);
/* 715 */         if (testCard != null) {
/* 716 */           String fontFamily = font.getNameTable().getRecord((short)1);
/* 717 */           writeSvgTestCard(ps, fontFamily);
/*     */         } 
/* 719 */         writeSvgEnd(ps);
/*     */ 
/*     */         
/* 722 */         if (fos != null) {
/* 723 */           fos.close();
/*     */         }
/*     */       } else {
/* 726 */         usage();
/*     */       } 
/*     */     } catch (Exception e) {
/* 729 */       e.printStackTrace();
/* 730 */       System.err.println(e.getMessage());
/* 731 */       usage();
/*     */     } 
/*     */   }
/*     */   
/*     */   private static void chopUpStringBuffer(StringBuffer sb) {
/* 736 */     if (sb.length() < 256) {
/*     */       return;
/*     */     }
/*     */ 
/*     */     
/* 741 */     for (int i = 240; i < sb.length(); i++) {
/* 742 */       if (sb.charAt(i) == ' ') {
/* 743 */         sb.setCharAt(i, '\n');
/* 744 */         i += 240;
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */   
/* 751 */   private static int midValue(int a, int b) { return a + (b - a) / 2; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static String parseArgs(String[] args, String name) {
/* 767 */     for (int i = 0; i < args.length; i++) {
/* 768 */       if (name == null) {
/* 769 */         if (args[i].charAt(0) != '-') {
/* 770 */           return args[i];
/*     */         }
/* 772 */       } else if (name.equalsIgnoreCase(args[i])) {
/* 773 */         if (i < args.length - 1 && args[i + 1].charAt(0) != '-') {
/* 774 */           return args[i + 1];
/*     */         }
/* 776 */         return args[i];
/*     */       } 
/*     */     } 
/*     */     
/* 780 */     return null;
/*     */   }
/*     */ 
/*     */   
/* 784 */   private static void usage() { System.err.println(Messages.formatMessage(CONFIG_USAGE, null)); }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svggen.jar!\org\apache\batik\svggen\font\SVGFont.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */