/*     */ package org.apache.batik.svggen.font.table;
/*     */ 
/*     */ import java.io.ByteArrayInputStream;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class GlyfCompositeDescript
/*     */   extends GlyfDescript
/*     */ {
/*  36 */   private List components = new ArrayList();
/*     */   
/*     */   protected boolean beingResolved = false;
/*     */   
/*     */   protected boolean resolved = false;
/*     */   
/*     */   public GlyfCompositeDescript(GlyfTable parentTable, ByteArrayInputStream bais) {
/*  43 */     super(parentTable, (short)-1, bais);
/*     */ 
/*     */ 
/*     */     
/*     */     do {
/*  48 */       comp = new GlyfCompositeComp(bais);
/*  49 */       this.components.add(comp);
/*  50 */     } while ((comp.getFlags() & 0x20) != 0);
/*     */ 
/*     */     
/*  53 */     if ((comp.getFlags() & 0x100) != 0) {
/*  54 */       readInstructions(bais, bais.read() << 8 | bais.read());
/*     */     }
/*     */   }
/*     */   
/*     */   public void resolve() {
/*  59 */     if (this.resolved)
/*  60 */       return;  if (this.beingResolved) {
/*  61 */       System.err.println("Circular reference in GlyfCompositeDesc");
/*     */       return;
/*     */     } 
/*  64 */     this.beingResolved = true;
/*     */     
/*  66 */     int firstIndex = 0;
/*  67 */     int firstContour = 0;
/*     */     
/*  69 */     Iterator i = this.components.iterator();
/*  70 */     while (i.hasNext()) {
/*  71 */       GlyfCompositeComp comp = (GlyfCompositeComp)i.next();
/*  72 */       comp.setFirstIndex(firstIndex);
/*  73 */       comp.setFirstContour(firstContour);
/*     */ 
/*     */       
/*  76 */       GlyfDescript desc = this.parentTable.getDescription(comp.getGlyphIndex());
/*  77 */       if (desc != null) {
/*  78 */         desc.resolve();
/*  79 */         firstIndex += desc.getPointCount();
/*  80 */         firstContour += desc.getContourCount();
/*     */       } 
/*     */     } 
/*  83 */     this.resolved = true;
/*  84 */     this.beingResolved = false;
/*     */   }
/*     */   
/*     */   public int getEndPtOfContours(int i) {
/*  88 */     GlyfCompositeComp c = getCompositeCompEndPt(i);
/*  89 */     if (c != null) {
/*  90 */       GlyphDescription gd = this.parentTable.getDescription(c.getGlyphIndex());
/*  91 */       return gd.getEndPtOfContours(i - c.getFirstContour()) + c.getFirstIndex();
/*     */     } 
/*  93 */     return 0;
/*     */   }
/*     */   
/*     */   public byte getFlags(int i) {
/*  97 */     GlyfCompositeComp c = getCompositeComp(i);
/*  98 */     if (c != null) {
/*  99 */       GlyphDescription gd = this.parentTable.getDescription(c.getGlyphIndex());
/* 100 */       return gd.getFlags(i - c.getFirstIndex());
/*     */     } 
/* 102 */     return 0;
/*     */   }
/*     */   
/*     */   public short getXCoordinate(int i) {
/* 106 */     GlyfCompositeComp c = getCompositeComp(i);
/* 107 */     if (c != null) {
/* 108 */       GlyphDescription gd = this.parentTable.getDescription(c.getGlyphIndex());
/* 109 */       int n = i - c.getFirstIndex();
/* 110 */       int x = gd.getXCoordinate(n);
/* 111 */       int y = gd.getYCoordinate(n);
/* 112 */       x1 = (short)c.scaleX(x, y);
/* 113 */       return (short)(x1 + c.getXTranslate());
/*     */     } 
/*     */     
/* 116 */     return 0;
/*     */   }
/*     */   
/*     */   public short getYCoordinate(int i) {
/* 120 */     GlyfCompositeComp c = getCompositeComp(i);
/* 121 */     if (c != null) {
/* 122 */       GlyphDescription gd = this.parentTable.getDescription(c.getGlyphIndex());
/* 123 */       int n = i - c.getFirstIndex();
/* 124 */       int x = gd.getXCoordinate(n);
/* 125 */       int y = gd.getYCoordinate(n);
/* 126 */       y1 = (short)c.scaleY(x, y);
/* 127 */       return (short)(y1 + c.getYTranslate());
/*     */     } 
/*     */     
/* 130 */     return 0;
/*     */   }
/*     */ 
/*     */   
/* 134 */   public boolean isComposite() { return true; }
/*     */ 
/*     */   
/*     */   public int getPointCount() {
/* 138 */     if (!this.resolved) {
/* 139 */       System.err.println("getPointCount called on unresolved GlyfCompositeDescript");
/*     */     }
/* 141 */     GlyfCompositeComp c = (GlyfCompositeComp)this.components.get(this.components.size() - 1);
/*     */ 
/*     */     
/* 144 */     return c.getFirstIndex() + this.parentTable.getDescription(c.getGlyphIndex()).getPointCount();
/*     */   }
/*     */   
/*     */   public int getContourCount() {
/* 148 */     if (!this.resolved) {
/* 149 */       System.err.println("getContourCount called on unresolved GlyfCompositeDescript");
/*     */     }
/* 151 */     GlyfCompositeComp c = (GlyfCompositeComp)this.components.get(this.components.size() - 1);
/* 152 */     return c.getFirstContour() + this.parentTable.getDescription(c.getGlyphIndex()).getContourCount();
/*     */   }
/*     */ 
/*     */   
/* 156 */   public int getComponentIndex(int i) { return ((GlyfCompositeComp)this.components.get(i)).getFirstIndex(); }
/*     */ 
/*     */ 
/*     */   
/* 160 */   public int getComponentCount() { return this.components.size(); }
/*     */ 
/*     */ 
/*     */   
/*     */   protected GlyfCompositeComp getCompositeComp(int i) {
/* 165 */     for (int n = 0; n < this.components.size(); n++) {
/* 166 */       GlyfCompositeComp c = (GlyfCompositeComp)this.components.get(n);
/* 167 */       GlyphDescription gd = this.parentTable.getDescription(c.getGlyphIndex());
/* 168 */       if (c.getFirstIndex() <= i && i < c.getFirstIndex() + gd.getPointCount()) {
/* 169 */         return c;
/*     */       }
/*     */     } 
/* 172 */     return null;
/*     */   }
/*     */ 
/*     */   
/*     */   protected GlyfCompositeComp getCompositeCompEndPt(int i) {
/* 177 */     for (int j = 0; j < this.components.size(); j++) {
/* 178 */       GlyfCompositeComp c = (GlyfCompositeComp)this.components.get(j);
/* 179 */       GlyphDescription gd = this.parentTable.getDescription(c.getGlyphIndex());
/* 180 */       if (c.getFirstContour() <= i && i < c.getFirstContour() + gd.getContourCount()) {
/* 181 */         return c;
/*     */       }
/*     */     } 
/* 184 */     return null;
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svggen.jar!\org\apache\batik\svggen\font\table\GlyfCompositeDescript.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */