/*     */ package org.apache.batik.svggen;
/*     */ 
/*     */ import java.io.ByteArrayOutputStream;
/*     */ import java.io.File;
/*     */ import java.io.FileInputStream;
/*     */ import java.io.FileOutputStream;
/*     */ import java.io.IOException;
/*     */ import java.io.OutputStream;
/*     */ import java.util.Arrays;
/*     */ import java.util.HashMap;
/*     */ import java.util.LinkedList;
/*     */ import java.util.ListIterator;
/*     */ import java.util.Map;
/*     */ import java.util.zip.Adler32;
/*     */ import java.util.zip.Checksum;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.Element;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class ImageCacher
/*     */   implements SVGSyntax, ErrorConstants
/*     */ {
/*  47 */   DOMTreeManager domTreeManager = null;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  55 */   Map imageCache = new HashMap();
/*  56 */   Checksum checkSum = new Adler32();
/*     */ 
/*     */ 
/*     */   
/*     */   public ImageCacher() {}
/*     */ 
/*     */ 
/*     */   
/*     */   public ImageCacher(DOMTreeManager domTreeManager) {
/*  65 */     this();
/*  66 */     setDOMTreeManager(domTreeManager);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setDOMTreeManager(DOMTreeManager domTreeManager) {
/*  75 */     if (domTreeManager == null) {
/*  76 */       throw new IllegalArgumentException();
/*     */     }
/*  78 */     this.domTreeManager = domTreeManager;
/*     */   }
/*     */ 
/*     */   
/*  82 */   public DOMTreeManager getDOMTreeManager() { return this.domTreeManager; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String lookup(ByteArrayOutputStream os, int width, int height, SVGGeneratorContext ctx) throws SVGGraphics2DIOException {
/* 105 */     int checksum = getChecksum(os.toByteArray());
/* 106 */     Integer key = new Integer(checksum);
/* 107 */     String href = null;
/*     */     
/* 109 */     Object data = getCacheableData(os);
/*     */     
/* 111 */     LinkedList list = (LinkedList)this.imageCache.get(key);
/* 112 */     if (list == null) {
/*     */       
/* 114 */       list = new LinkedList();
/* 115 */       this.imageCache.put(key, list);
/*     */     } else {
/*     */       
/* 118 */       for (ListIterator i = list.listIterator(0); i.hasNext(); ) {
/* 119 */         ImageCacheEntry entry = (ImageCacheEntry)i.next();
/* 120 */         if (entry.checksum == checksum && imagesMatch(entry.src, data)) {
/* 121 */           href = entry.href;
/*     */           
/*     */           break;
/*     */         } 
/*     */       } 
/*     */     } 
/* 127 */     if (href == null) {
/*     */       
/* 129 */       ImageCacheEntry newEntry = createEntry(checksum, data, width, height, ctx);
/*     */ 
/*     */       
/* 132 */       list.add(newEntry);
/* 133 */       href = newEntry.href;
/*     */     } 
/*     */     
/* 136 */     return href;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   abstract Object getCacheableData(ByteArrayOutputStream paramByteArrayOutputStream);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   abstract boolean imagesMatch(Object paramObject1, Object paramObject2) throws SVGGraphics2DIOException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   abstract ImageCacheEntry createEntry(int paramInt1, Object paramObject, int paramInt2, int paramInt3, SVGGeneratorContext paramSVGGeneratorContext) throws SVGGraphics2DIOException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   int getChecksum(byte[] data) {
/* 179 */     this.checkSum.reset();
/* 180 */     this.checkSum.update(data, 0, data.length);
/* 181 */     return (int)this.checkSum.getValue();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static class ImageCacheEntry
/*     */   {
/*     */     public int checksum;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Object src;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public String href;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     ImageCacheEntry(int checksum, Object src, String href) {
/* 206 */       this.checksum = checksum;
/* 207 */       this.src = src;
/* 208 */       this.href = href;
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static class Embedded
/*     */     extends ImageCacher
/*     */   {
/*     */     public void setDOMTreeManager(DOMTreeManager domTreeManager) {
/* 225 */       if (this.domTreeManager != domTreeManager) {
/* 226 */         this.domTreeManager = domTreeManager;
/* 227 */         this.imageCache = new HashMap();
/*     */       } 
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 235 */     Object getCacheableData(ByteArrayOutputStream os) { return "data:image/png;base64," + os.toString(); }
/*     */ 
/*     */ 
/*     */     
/* 239 */     boolean imagesMatch(Object o1, Object o2) throws SVGGraphics2DIOException { return o1.equals(o2); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     ImageCacher.ImageCacheEntry createEntry(int checksum, Object data, int width, int height, SVGGeneratorContext ctx) throws SVGGraphics2DIOException {
/* 247 */       String id = ctx.idGenerator.generateID("image");
/*     */ 
/*     */       
/* 250 */       addToTree(id, (String)data, width, height, ctx);
/*     */ 
/*     */       
/* 253 */       return new ImageCacher.ImageCacheEntry(checksum, data, "#" + id);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private void addToTree(String id, String href, int width, int height, SVGGeneratorContext ctx) {
/* 264 */       Document domFactory = this.domTreeManager.getDOMFactory();
/*     */ 
/*     */ 
/*     */       
/* 268 */       Element imageElement = domFactory.createElementNS("http://www.w3.org/2000/svg", "image");
/*     */       
/* 270 */       imageElement.setAttributeNS(null, "id", id);
/*     */       
/* 272 */       imageElement.setAttributeNS(null, "width", Integer.toString(width));
/*     */       
/* 274 */       imageElement.setAttributeNS(null, "height", Integer.toString(height));
/*     */       
/* 276 */       imageElement.setAttributeNS("http://www.w3.org/1999/xlink", "xlink:href", href);
/*     */ 
/*     */ 
/*     */       
/* 280 */       this.domTreeManager.addOtherDef(imageElement);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static class External
/*     */     extends ImageCacher
/*     */   {
/*     */     private String imageDir;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private String prefix;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private String suffix;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public External(String imageDir, String prefix, String suffix) {
/* 318 */       this.imageDir = imageDir;
/* 319 */       this.prefix = prefix;
/* 320 */       this.suffix = suffix;
/*     */     }
/*     */ 
/*     */     
/* 324 */     Object getCacheableData(ByteArrayOutputStream os) { return os; }
/*     */ 
/*     */ 
/*     */     
/*     */     boolean imagesMatch(Object o1, Object o2) throws SVGGraphics2DIOException {
/* 329 */       boolean match = false;
/*     */       try {
/* 331 */         FileInputStream imageStream = new FileInputStream((File)o1);
/*     */         
/* 333 */         int imageLen = imageStream.available();
/* 334 */         byte[] imageBytes = new byte[imageLen];
/* 335 */         byte[] candidateBytes = ((ByteArrayOutputStream)o2).toByteArray();
/*     */ 
/*     */         
/* 338 */         int bytesRead = 0;
/* 339 */         while (bytesRead != imageLen) {
/* 340 */           bytesRead += imageStream.read(imageBytes, bytesRead, imageLen - bytesRead);
/*     */         }
/*     */ 
/*     */         
/* 344 */         match = Arrays.equals(imageBytes, candidateBytes);
/*     */       } catch (IOException e) {
/* 346 */         throw new SVGGraphics2DIOException("could not read image File " + ((File)o1).getName());
/*     */       } 
/*     */       
/* 349 */       return match;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     ImageCacher.ImageCacheEntry createEntry(int checksum, Object data, int width, int height, SVGGeneratorContext ctx) throws SVGGraphics2DIOException {
/* 358 */       File imageFile = null;
/*     */ 
/*     */ 
/*     */       
/*     */       try {
/* 363 */         while (imageFile == null) {
/* 364 */           String fileId = ctx.idGenerator.generateID(this.prefix);
/* 365 */           imageFile = new File(this.imageDir, fileId + this.suffix);
/* 366 */           if (imageFile.exists()) {
/* 367 */             imageFile = null;
/*     */           }
/*     */         } 
/*     */         
/* 371 */         OutputStream outputStream = new FileOutputStream(imageFile);
/* 372 */         ((ByteArrayOutputStream)data).writeTo(outputStream);
/* 373 */         ((ByteArrayOutputStream)data).close();
/*     */       } catch (IOException e) {
/* 375 */         throw new SVGGraphics2DIOException("could not write image File " + imageFile.getName());
/*     */       } 
/*     */ 
/*     */       
/* 379 */       return new ImageCacher.ImageCacheEntry(checksum, imageFile, imageFile.getName());
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-svggen.jar!\org\apache\batik\svggen\ImageCacher.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */